//
//  VirtualMachine.h
//  JDBCDiscoveryC
//
//  Created by Angus Hardie on 11/08/2005.
//  Copyright 2005 MalcolmHardie Solutions Ltd. All rights reserved.
//

#import <Cocoa/Cocoa.h>
#import "jni.h"


@interface VirtualMachine : NSObject {
   JNIEnv *env;
   JavaVM *jvm;
   
   jclass _throwableClass;
   jclass _classClass;
   jclass _objectClass;
   jmethodID _getMessageMethodID;
   jmethodID _toStringMethodID;
   jmethodID _classGetNameMethodID;
   jmethodID _objectGetClassMethodID;
    
    id _bundle;
    
    NSDictionary* jvmDetails;
}

@property (retain) NSDictionary* jvmDetails;

- (id)initWithBundle:(NSBundle*)activeBundle;
- (JNIEnv*)env;
+ (id)sharedVM;
+ (id)sharedVMWithBundle:(id)bundle;
/*- (jobject)callMethod:(jmethodID)methodID class:(jclass)objectClass;
- (jmethodID)getMethodID:(NSString*)methodName class:(jclass)objectClass argList:(NSString*)argList;
*/

- (NSString*)jvmVersion;

- (jclass)findClass:(NSString*)className;
- (jstring)NewStringUTF:(NSString*)newString;


- (jfieldID)GetFieldID:(jclass)theClass fieldName:(NSString*)fieldName withSignature:(NSString*)signature isStatic:(BOOL)isStatic;
- (int)GetIntField:(jobject) obj fieldID:(jfieldID) fieldID;
- (short)GetShortStaticField:(jclass) obj fieldID:(jfieldID) fieldID;

- (jmethodID)GetMethodID:(jclass)theClass methodName:(NSString*)methodName withSignature:(NSString*)signature;
- (jmethodID)GetMethodID:(jclass)theClass methodName:(NSString*)methodName withSignature:(NSString*)signature isOptional:(BOOL)isOptional;

-(jboolean)CallBooleanMethod:(jobject)theObject methodID:(jmethodID)methodID, ...;
-(jboolean)CallBooleanMethod:(jobject)theObject methodID:(jmethodID)methodID args:(va_list)argList;


-(jobject)CallObjectMethod:(jobject)theObject methodID:(jmethodID)methodID, ...;
-(jobject)CallObjectMethod:(jobject)theObject methodID:(jmethodID)methodID args:(va_list)argList;
-(jobject)CallObjectMethod:(jobject)theObject methodID:(jmethodID)methodID argArray:(jvalue*)argList;

-(NSString*)CallStringObjectMethod:(jobject)theObject methodID:(jmethodID)methodID, ...;
-(NSString*)CallStringObjectMethod:(jobject)theObject methodID:(jmethodID)methodID args:(va_list)argList;

- (void)testForException;
- (void)testForException:(NSString*)exceptionName;

- (NSString*)classNameForObject:(jobject)theObject;
- (NSString*)nameForClass:(jclass)theClass;
- (jclass)jclassForObject:(jobject)theObject;

- (jvalue*)jvalueCArrayFromArray:(NSArray*)argList;

- (jobject)jobjectWithClass:(jclass)classObject withConstructorSignature:(NSString*)constructorSignature;
- (jobject)jobjectWithClass:(jclass)classObject;



- (id)objectOfClass:(NSString*)className;
- (id)objectOfClass:(NSString*)className withConstructorSignature:(NSString*)constructorSignature;

- (jobject)jobjectOfClass:(NSString*)className;

-(void)CallVoidMethod:(jobject)theObject methodID:(jmethodID)methodID, ...;
-(void)CallVoidMethod:(jobject)theObject methodID:(jmethodID)methodID args:(va_list)argList;

-(jint)CallIntMethod:(jobject)theObject methodID:(jmethodID)methodID, ...;
-(jint)CallIntMethod:(jobject)theObject methodID:(jmethodID)methodID args:(va_list)argList;

- (NSString*)stringForJString:(jstring)theJString;

- (void)javaDebugObject:(jobject)theObject;
- (void)javaObjectPrintString:(jobject)theObject;

- (void)DeleteLocalRef:(jobject)theObject;
- (jobject)NewGlobalRef:(jobject)theObject;
- (void)DeleteGlobalRef:(jobject)theObject;

- (jobject)makeOrReturnGlobalRef:(jobject)theObject;

- (jint)PushLocalFrame:(jint)capacity;
- (jobject)PopLocalFrame:(jobject)resultObject;
- (jint)EnsureLocalCapacity:(jint)capacity;
@end
